      subroutine find_wall_1D(dt,ioffset,ri,rip1,ux,uy,uz,x1,y1,z1)
c
c   This routine calculates the distance to all faces of a grid cell
c   (in a spherical symmetric grid-- r, 1D) from a point (x1,y1,z1) along the
c   directional cosine vector (ux,uy,yz).
c
c  Output values:
c     dt = distance from (x1,y1,z1) along (ux,uy,uz) to closest face.
c     ioffset = integer offsets for new cell position.  **NOTE** 
c  	ioffset=-1 indicates face at "ri" is closest while
c   	ioffset=1 indicates face at "rip1" is closest.
c   
c
c  Input values:
c     ri,rip1 = radii of two constant surfaces r(i),r(i+1)
c     ux,uy,uz = directional cosines along x,y,z directions
c     x1,y1,z1 = point from which distance is calculated
c
c m.j. wolff/b.a. whitney, 2000/02/09
c history:
c 00/02/18 (mjw):  trap case of point on wall surface (i.e. t=0 ) and 
c                     force ioffset=0.
c 00/02/28 (mjw):  removed t=0 as possible choice (RADFACE will not pass
c		      back as such).  NOW: only offset values are
c                     -1 or 1.
c


      implicit none
c ... 
      integer ioffset
      real dt
      real ri,rip1,ux,uy,uz,x1,y1,z1

c ..
      integer iface
      real t
      integer idist
      logical ifound

c find shortest positive distance to two constant radius surfaces
c where negative ifound = .false. indicates no intersection.  This
c SHOULD never happen...
      call radface(iface,ifound,t,ux,uy,uz,x1,y1,z1,ri,rip1)
      idist = iface
c      print*,'RAD - iface,ifound,t:',iface,ifound,t

c t=0 is NOT allowed to be "shortest distance".  offsets
c are either -1 or 1.  if "ri" is closest face, then idist=0.
c if "rip1" is closest, then idist=1
      ioffset = -1 + 2*idist

c set "winning distance" to dt to pass back
      dt = t

      return
      end
